from flask_discord_interactions.models.channel import Channel, ChannelType
from flask_discord_interactions.models.user import User, Member
from flask_discord_interactions.models.message import Message, ResponseType
from flask_discord_interactions.models.embed import Embed
from flask_discord_interactions.models.component import (
    ComponentType, ActionRow, Button, SelectMenu, SelectMenuOption, Component, ButtonStyles
)
from flask_discord_interactions.models.command import ApplicationCommandType, CommandOptionType
from flask_discord_interactions.models.permission import Permission
from flask_discord_interactions.models.role import Role
from flask_discord_interactions.models.utils import LoadableDataclass

__all__ = [
    "Channel",
    "ChannelType",
    "User",
    "Member",
    "Message",
    "ResponseType",
    "Embed",
    "ComponentType",
    "ActionRow",
    "Button",
    "SelectMenu",
    "SelectMenuOption",
    "Component",
    "ButtonStyles",
    "ApplicationCommandType",
    "CommandOptionType",
    "Permission",
    "Role",
    "LoadableDataclass",
]


class ApplicationCommandType:
    "Represents the different application command types integers."
    CHAT_INPUT = 1
    USER = 2
    MESSAGE = 3


class CommandOptionType:
    "Represents the different option type integers."
    SUB_COMMAND = 1
    SUB_COMMAND_GROUP = 2
    STRING = 3
    INTEGER = 4
    BOOLEAN = 5
    USER = 6
    CHANNEL = 7
    ROLE = 8
    MENTIONABLE = 9
    NUMBER = 10
